AndroidDynamicColors class final

Constructors

AndroidDynamicColors()
factory

Properties

allDynamicColors List<DynamicColor Function()>
All dynamic colors in Android Design system.
latefinal
brandA DynamicColor
One of the colors used in the Super G logo. Super G is the internal name of the multicolored Google "G" logomark.
latefinal
brandB DynamicColor
One of the colors used in the Super G logo. Super G is the internal name of the multicolored Google "G" logomark.
latefinal
brandC DynamicColor
One of the colors used in the Super G logo. Super G is the internal name of the multicolored Google "G" logomark.
latefinal
brandD DynamicColor
One of the colors used in the Super G logo. Super G is the internal name of the multicolored Google "G" logomark.
latefinal
clockHour DynamicColor
Clock hour color
latefinal
clockMinute DynamicColor
Clock minute color
latefinal
clockSecond DynamicColor
Clock second color
latefinal
hashCode int
The hash code for this object.
no setterinherited
onShadeActive DynamicColor
latefinal
onShadeActiveVariant DynamicColor
latefinal
onShadeInactive DynamicColor
latefinal
onShadeInactiveVariant DynamicColor
latefinal
onThemeApp DynamicColor
Tint color that gets applied to monochrome launcher icons.
latefinal
overviewBackground DynamicColor
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadeActive DynamicColor
latefinal
shadeDisabled DynamicColor
latefinal
shadeInactive DynamicColor
latefinal
surfaceEffect0 DynamicColor
latefinal
surfaceEffect0Fallback DynamicColor
latefinal
surfaceEffect1 DynamicColor
latefinal
surfaceEffect2 DynamicColor
latefinal
surfaceEffect3 DynamicColor
latefinal
themeApp DynamicColor
Background color of monochrome launcher icons containers.
latefinal
themeAppRing DynamicColor
App suggestion ring color.
latefinal
themeNotif DynamicColor
App notification badge color.
latefinal
underSurface DynamicColor
latefinal
weatherTemp DynamicColor
Weather temperature color
latefinal
widgetBackground DynamicColor
Background color recommended for most Android widgets.
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited