QuantizerWu class final

An image quantizer that divides the image's pixels into clusters by recursively cutting an RGB cube, based on the weight of pixels in each area of the cube.

The algorithm was described by Xiaolin Wu in Graphic Gems II, published in 1991.

Implemented types

Constructors

QuantizerWu()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
quantize(List<int> pixels, int maxColors) QuantizerResult
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited