TemperatureCache class final

Design utilities using color temperature theory.

Analogous colors, complementary color, and cache to efficiently, lazily, generate data for calculations when needed.

Constructors

TemperatureCache(Hct input)

Properties

complement Hct
A color that complements the input color aesthetically.
no setter
hashCode int
The hash code for this object.
no setterinherited
input Hct
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAnalogousColors([int count = 5, int divisions = 12]) List<Hct>
A set of colors with differing hues, equidistant in temperature.
getRelativeTemperature(Hct hct) double
Temperature relative to all colors with the same chroma and tone.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

rawTemperature(Hct color) double
Value representing cool-warm factor of a color. Values below 0 are considered cool, above, warm.