ViewingConditions class final

In traditional color spaces, a color can be identified solely by the observer's measurement of the color. Color appearance models such as CAM16 also use information about the environment where the color was observed, known as the viewing conditions.

For example, white under the traditional assumption of a midday sun white point is accurately measured as a slightly chromatic blue by CAM16. (roughly, hue 203, chroma 3, lightness 100)

This class caches intermediate values of the CAM16 conversion process that depend only on viewing conditions, enabling speed ups.

Constructors

ViewingConditions.defaultWithBackgroundLstar(double lstar)
Create sRGB-like viewing conditions with a custom background lstar.
factory
ViewingConditions.make(List<double> whitePoint, double adaptingLuminance, double backgroundLstar, double surround, bool discountingIlluminant)
Create ViewingConditions from a simple, physically relevant, set of parameters.
factory

Properties

aw double
final
c double
final
fl double
final
flRoot double
final
hashCode int
The hash code for this object.
no setteroverride
n double
final
nbb double
final
nc double
final
ncb double
final
rgbD List<double>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
z double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Properties

srgb ViewingConditions
sRGB-like viewing conditions.
final