getInt static method

int getInt(
  1. double hue,
  2. double chroma,
  3. double lstar
)

Given a hue & chroma in CAM16, L* in Lab*, return an ARGB integer.

The chroma of the color returned may, and frequently will, be lower than requested. This is a fundamental property of color that cannot be worked around by engineering. For example, a red hue, with high chroma, and high L* does not exist: red hues have a maximum chroma below 10 in light shades, creating pink.

Implementation

static int getInt(double hue, double chroma, double lstar) =>
    getIntInViewingConditions(hue, chroma, lstar, .srgb);