Hct class final

HCT, hue, chroma, and tone. A color system that provides a perceptually accurate color measurement system that can also accurately render what colors will appear as in different lighting environments.

Constructors

Hct.from(double hue, double chroma, double tone)
Create an HCT color from hue, chroma, and tone.
factory
Hct.fromInt(int argb)
Create an HCT color from a color.
factory

Properties

chroma double
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
hue double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tone double
getter/setter pair

Methods

inViewingConditions(ViewingConditions vc) Hct
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toInt() int
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

isBlue(double hue) bool
isCyan(double hue) bool
isYellow(double hue) bool