Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
solveToCam(double hueDegrees, double chroma, double lstar)
→ Cam16
-
Finds an sRGB color with the given hue, chroma, and L*, if possible.
-
solveToInt(double hueDegrees, double chroma, double lstar)
→ int
-
Finds an sRGB color with the given hue, chroma, and L*, if possible.