TonalPalette class final
A convenience class for retrieving colors that are in hue and chroma, but vary in tone.
TonalPalette is intended for use in a single thread due to its stateful caching.
Constructors
- TonalPalette.fromHct(Hct hct)
- Create tones using a HCT color.
- TonalPalette.fromHueAndChroma(double hue, double chroma)
- Create tones from a defined HCT hue and chroma.
- TonalPalette.fromInt(int argb)
- Create tones using the HCT hue and chroma from a color.
Properties
Methods
-
getHct(
double tone) → Hct - Given a tone, use hue and chroma of palette to create a color, and return it as HCT.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tone(
int tone) → int - Create an ARGB color with HCT hue and chroma of this Tones instance, and the provided HCT tone.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited