TonalPaletteSourceColor class abstract
Constructors
- TonalPaletteSourceColor()
-
const
- TonalPaletteSourceColor.fromArgb(int argb)
-
factory
-
TonalPaletteSourceColor.fromArgbList(List<
int> argbList) -
factory
- TonalPaletteSourceColor.fromHct(Hct hct)
-
factory
-
TonalPaletteSourceColor.fromHctList(List<
Hct> hctList) -
factory
Properties
- asArgb → int
-
The source color in ARGB format.
no setter
-
asArgbList
→ List<
int> -
The source color in ARGB format.
no setter
- asHct → Hct
-
The source color in HCT format.
no setter
-
asHctList
→ List<
Hct> -
The source color in HCT format.
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
argbListEquality
→ const ListEquality<
int> -
hctListEquality
→ const ListEquality<
Hct>