TonePolarity enum

Describes the relationship in lightness between two colors.

'relative_darker' and 'relative_lighter' describes the tone adjustment relative to the surface color trend (white in light mode; black in dark mode). For instance, ToneDeltaPair(A, B, 10, 'relative_lighter', 'farther') states that A should be at least 10 lighter than B in light mode, and at least 10 darker than B in dark mode.

Inheritance
Available extensions

Values

darker → const TonePolarity

The tone of roleA is always darker than the tone of roleB.

lighter → const TonePolarity

The tone of roleA is always lighter than the tone of roleB.

relativeDarker → const TonePolarity

The tone of roleA is darker than the tone of roleB in light mode, and lighter than the tone of roleB in dark mode.

relativeLighter → const TonePolarity

The tone of roleA is lighter than the tone of roleB in light mode, and darker than the tone of roleB in dark mode.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TonePolarity>
A constant List of the values in this enum, in order of their declaration.