brandA property
One of the colors used in the Super G logo. Super G is the internal name of the multicolored Google "G" logomark.
This color maps to the red part of the logo.
Implementation
late final DynamicColor brandA = DynamicColor(
name: "brand_a",
palette: (scheme) => scheme.primaryPalette,
tone: (scheme) => scheme.isDark ? 80.0 : 40.0,
background: (_) => _materialDynamicColors.surfaceContainerLow,
contrastCurve: (scheme) => scheme.isDark
? const ContrastCurve(10.0, 10.0, 12.0, 13.0)
: const ContrastCurve(6.0, 6.0, 9.0, 12.0),
);