brandD property
One of the colors used in the Super G logo. Super G is the internal name of the multicolored Google "G" logomark.
This color maps to the blue part of the logo.
Implementation
late final DynamicColor brandD = DynamicColor(
name: "brand_d",
palette: (scheme) => scheme.tertiaryPalette,
tone: (scheme) => scheme.isDark ? 90.0 : 59.0,
background: (_) => _materialDynamicColors.surfaceContainerLow,
contrastCurve: (scheme) => scheme.isDark
? const ContrastCurve(13.0, 13.0, 14.0, 15.0)
: const ContrastCurve(3.0, 3.0, 4.5, 6.0),
);