SpecVersion enum
All available spec versions.
- Inheritance
- Implemented types
- Available extensions
Values
- spec2021 → const SpecVersion
-
const SpecVersion(2021) - spec2025 → const SpecVersion
-
const SpecVersion(2025) - spec2026 → const SpecVersion
-
const SpecVersion(2026)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- year → int
-
final
Methods
-
compareTo(
SpecVersion other) → int -
Compares this object to another object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator <(
SpecVersion other) → bool -
operator <=(
SpecVersion other) → bool -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator >(
SpecVersion other) → bool -
operator >=(
SpecVersion other) → bool
Constants
-
values
→ const List<
SpecVersion> - A constant List of the values in this enum, in order of their declaration.